config_settings
================

.. automodule:: drain_swamp.monkey.config_settings
   :members:
   :undoc-members:
   :platform: Unix
   :synopsis: Accepting and deliver of config_settings to the build command
